summaryrefslogtreecommitdiff
path: root/nuttx/configs/shenzhou/src/up_buttons.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/shenzhou/src/up_buttons.c')
-rw-r--r--nuttx/configs/shenzhou/src/up_buttons.c14
1 files changed, 8 insertions, 6 deletions
diff --git a/nuttx/configs/shenzhou/src/up_buttons.c b/nuttx/configs/shenzhou/src/up_buttons.c
index 5a8515ca5..c9d2e4f1f 100644
--- a/nuttx/configs/shenzhou/src/up_buttons.c
+++ b/nuttx/configs/shenzhou/src/up_buttons.c
@@ -1,7 +1,7 @@
/****************************************************************************
* configs/shenzhou/src/up_buttons.c
*
- * Copyright (C) 2012 Gregory Nutt. All rights reserved.
+ * Copyright (C) 2012, 2014 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
*
* Redistribution and use in source and binary forms, with or without
@@ -41,7 +41,9 @@
#include <stdint.h>
+#include <nuttx/arch.h>
#include <arch/board/board.h>
+
#include "shenzhou-internal.h"
#ifdef CONFIG_ARCH_BUTTONS
@@ -71,17 +73,17 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
****************************************************************************/
/****************************************************************************
- * Name: up_buttoninit
+ * Name: board_button_initialize
*
* Description:
* up_buttoninit() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
-void up_buttoninit(void)
+void board_button_initialize(void)
{
int i;
@@ -133,12 +135,12 @@ uint8_t up_buttons(void)
* Button support.
*
* Description:
* up_buttoninit() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After up_buttoninit() has been called, up_buttons() may be called to
* collect the state of all buttons. up_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT
* definitions in board.h for the meaning of each bit.
@@ -71,17 +73,17 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
*
* Description:
- * up_buttoninit() must be called to initialize button resources. After
+ * board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
@@ -133,12 +135,12 @@ uint8_t up_buttons(void)
*
* Description:
- * up_buttoninit() must be called to initialize button resources. After
+ * board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
@@ -133,12 +135,12 @@ uint8_t up_buttons(void)
* handlers.
*
- * After up_buttoninit() has been called, up_buttons() may be called to
+ * After board_button_initialize() has been called, up_buttons() may be called to
* collect the state of all buttons. up_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT